@@ -4,7 +4,7 @@ set -eux
 
 group=local
 
-cd ../connection
+pushd ../connection
 
 INVENTORY="../connection_${group}/test_connection.inventory" ./test.sh \
     -e target_hosts="${group}" \
@@ -19,3 +19,7 @@ ANSIBLE_CONNECTION_PLUGINS="../connection_${group}/connection_plugins" INVENTORY
     -e local_tmp=/tmp/ansible-local \
     -e remote_tmp=/tmp/ansible-remote \
     "$@"
+
+popd
+
+ANSIBLE_ROLES_PATH=../ ansible-playbook -i ../../inventory test_become_password_handling.yml "$@"
